==> babel-plugin-short-private-properties-1.0.0.tgz: package/lib/MapHash.js <==
function _classCallCheck(instance, Constructor) {
	if (!(instance instanceof Constructor)) {
		throw new TypeError("Cannot call a class as a function");
	}
}

function _defineProperties(target, props) {
	for (var i = 0; i < props.length; i++) {
		var descriptor = props[i];
		descriptor.enumerable = descriptor.enumerable || false;
		descriptor.configurable = true;
		if ("value" in descriptor) descriptor.writable = true;
		Object.defineProperty(target, descriptor.key, descriptor);
	}
}

function _createClass(Constructor, protoProps, staticProps) {
	if (protoProps) _defineProperties(Constructor.prototype, protoProps);
	if (staticProps) _defineProperties(Constructor, staticProps);
	return Constructor;
}

var crypto = require("crypto");

var _require = require("./util.js"),
	initStepNames = _require.initStepNames;

module.exports.MapHash =
	/*#__PURE__*/
	(function() {
		function MapHash(AllClassMap) {
			_classCallCheck(this, MapHash);

			this._AllClassMap = AllClassMap;
			this._getShortName = initStepNames(["a-z", "A-Z"]);
			this._shortNames = new Map();
		}

		_createClass(MapHash, [
			{
				key: "_createHash",
				value: function _createHash(name) {
					return crypto
						.createHash("md4")
						.update(name + "salt :)")
						.digest("base64");
				}
			},
			{
				key: "clear",
				value: function clear() {
					return this._shortNames.clear();
				}
			},
			{
				key: "getName",
				value: function getName() {
					var hasInSuperClass = this._findInSuperClass.apply(this, arguments);

					if (hasInSuperClass === false) {
						return this._createNew.apply(this, arguments);
					}

					return hasInSuperClass;
				}
			},
			{
				key: "_createNew",
				value: function _createNew(identifierName, classDeclNode) {
					var hash = this._createHash(identifierName + classDeclNode.id.name);

					if (this._shortNames.has(hash) === false) {
						this._shortNames.set(hash, `_${this._getShortName()}`);
					}

					return this._shortNames.get(hash);
				}
			},
			{
				key: "_findInSuperClass",
				value: function _findInSuperClass(identifierName, _ref) {
					var superClass = _ref.superClass;

					if (superClass !== null) {
						var hash = this._createHash(identifierName + superClass.name);

						if (this._shortNames.has(hash) === true) {
							return this._shortNames.get(hash);
						} else {
							var classNode = this._AllClassMap.get(superClass.name);

							return this._findInSuperClass(identifierName, classNode);
						}
					}

					return false;
				}
			}
		]);

		return MapHash;
	})();

==> babel-plugin-short-private-properties-1.0.1.tgz: package/lib/MapHash.js <==
function _classCallCheck(instance, Constructor) {
	if (!(instance instanceof Constructor)) {
		throw new TypeError("Cannot call a class as a function");
	}
}

function _defineProperties(target, props) {
	for (var i = 0; i < props.length; i++) {
		var descriptor = props[i];
		descriptor.enumerable = descriptor.enumerable || false;
		descriptor.configurable = true;
		if ("value" in descriptor) descriptor.writable = true;
		Object.defineProperty(target, descriptor.key, descriptor);
	}
}

function _createClass(Constructor, protoProps, staticProps) {
	if (protoProps) _defineProperties(Constructor.prototype, protoProps);
	if (staticProps) _defineProperties(Constructor, staticProps);
	return Constructor;
}

var crypto = require("crypto");

var _require = require("./util.js"),
	initStepNames = _require.initStepNames;

module.exports.MapHash =
	/*#__PURE__*/
	(function() {
		function MapHash(AllClassMap) {
			_classCallCheck(this, MapHash);

			this._AllClassMap = AllClassMap;
			this._getShortName = initStepNames(["a-z", "A-Z"]);
			this._shortNames = new Map();
		}

		_createClass(MapHash, [
			{
				key: "_createHash",
				value: function _createHash(name) {
					return crypto
						.createHash("md4")
						.update(name + "salt :)")
						.digest("base64");
				}
			},
			{
				key: "clear",
				value: function clear() {
					return this._shortNames.clear();
				}
			},
			{
				key: "getName",
				value: function getName() {
					var hasInSuperClass = this._findInSuperClass.apply(this, arguments);

					if (hasInSuperClass === false) {
						return this._createNew.apply(this, arguments);
					}

					return hasInSuperClass;
				}
			},
			{
				key: "_createNew",
				value: function _createNew(identifierName, classDeclNode) {
					var hash = this._createHash(identifierName + classDeclNode.id.name);

					if (this._shortNames.has(hash) === false) {
						this._shortNames.set(hash, `_${this._getShortName()}`);
					}

					return this._shortNames.get(hash);
				}
			},
			{
				key: "_findInSuperClass",
				value: function _findInSuperClass(identifierName) {
					var node =
						arguments.length > 1 && arguments[1] !== undefined
							? arguments[1]
							: {};
					var superClass = node.superClass;

					if (superClass) {
						var hash = this._createHash(identifierName + superClass.name);

						if (this._shortNames.has(hash) === true) {
							return this._shortNames.get(hash);
						} else {
							var classNode = this._AllClassMap.get(superClass.name);

							return this._findInSuperClass(identifierName, classNode);
						}
					}

					return false;
				}
			}
		]);

		return MapHash;
	})();
